@@ -122,7 +122,10 @@ class ECIFitDashboard(BaseDashboard):
         evaluator.get_eci()
         self.set_evaluator(evaluator)
         eci = evaluator.get_eci_dict()
+        # Count the number of non-zero ECI's and log
         self.set_eci(eci)
+        num_eci = sum(1 for val in eci.values() if abs(val) > 1e-5)
+        logger.info("Number of non-zero ECI: %d", num_eci)
         logger.info("Fitting complete.")
 
     def set_evaluator(self, evaluator):
@@ -137,7 +140,7 @@ class ECIFitDashboard(BaseDashboard):
         with self.event_context(logger=logger) as cm:
             self.fit_eci()
         if not cm.success:
-            logger.warning("Failed to fit")
+            logger.error("Failed to fit")
 
     def set_eci(self, value):
         self.app_data[self.KEYS.ECI] = value
