@@ -24,21 +24,24 @@ register_logger(logger)
 
 
 class _SubDashboard(NamedTuple):
-    dashboard: BaseDashboard
+    dashboard: BaseDashboard  # Instance of the Dashboard
     tab_name: str
-    # dash_out: widgets.Output
+
+    def make_output(self) -> widgets.Output:
+        """Make a new output object, and draw the dashboard on it."""
+        out = widgets.Output()
+        with out:
+            clear_output()
+            self.dashboard.display()
+        return out
 
 
 def _make_subtab(*sub_dashboards: _SubDashboard) -> widgets.Tab:
     """Construct the tabs in the sub-dashboards, and initialize their displays"""
-    children = [widgets.Output() for _ in sub_dashboards]
+    children = [sub.make_output() for sub in sub_dashboards]
     tab = widgets.Tab(children=children)
-    for ii, subdash in enumerate(sub_dashboards):
-        tab.set_title(ii, subdash.tab_name)
-        output_widget = children[ii]  # The Output object we draw the dashboard on
-        with output_widget:
-            clear_output()
-            subdash.dashboard.display()
+    for ii, sub in enumerate(sub_dashboards):
+        tab.set_title(ii, sub.tab_name)
     return tab
 
 
